@@ -25,9 +25,6 @@ common_display_setup() {
 
         echo 0 > /sys/class/graphics/fb1/free_scale
         echo 1 > /sys/class/graphics/fb1/freescale_mode
-        if [ "$bpp" = "32" ]; then
-            echo d01068b4 0x7fc0 > /sys/kernel/debug/aml_reg/paddr
-        fi
 }
 
 case $mode in
@@ -115,6 +112,10 @@ case $mode in
 			export X=2560
 			export Y=1600
 			;;
+		3440x1440p60hz*)
+			export X=3440
+			export Y=1440
+			;;
 esac
 
 common_display_setup
